@@ -9,7 +9,7 @@ from onnx.reference.ops.op_softmax import Softmax
 
 
 class LogSoftmax(Softmax):
-    def _run(self, X):  # type: ignore
+    def _run(self, X):
         Y = Softmax._run(self, X)[0]
         np.log(Y, out=Y)
         return (Y,)
